docs.rs failed to build ghosttea-vt-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
ghosttea-vt
Safe Rust wrapper around the Ghostty libghostty-vt terminal core used by
Ghosttea.
Native artifact resolution and linking are delegated to ghosttea-vt-sys.
The safe wrapper does not bundle or build Ghostty itself.